@@ -1,11 +1,8 @@
 from .__version__ import __version__
-from . import parameters
 from .cleanups import add_cleanup, add_critical_cleanup
 from .conf import config
 from .ctx import context
 from .ctx import g, session, test
-from .runnable_test_factory import RunnableTestFactory
-from .runnable_test import RunnableTest
 from .core.session import Session
 # assertions
 from . import assertions
@@ -34,7 +31,8 @@ from .assertions import (
     )
 from .core.test import Test
 from .core.test import abstract_test_class
-from .test_context import TestContext, with_context
+from .core.fixtures import parametrize, parameters
+from .core.fixtures.utils import fixture
 from .utils import skip_test, skipped, add_error, add_failure
 from .app import get_application_context
 from .runner import run_tests
