@@ -32,14 +32,16 @@ if PY2:
     from cStringIO import StringIO
     iteritems = lambda d: d.iteritems() # not dict.iteritems!!! we support ordered dicts as well
     itervalues = lambda d: d.itervalues()
-    from itertools import imap as map
-    from itertools import izip as zip
+    from itertools import imap
+    reduce = _builtins.reduce
+    from itertools import izip
     from itertools import izip_longest
     xrange = _builtins.xrange
 else:
     from io import StringIO
-    zip = _builtins.zip
-    map = _builtins.map
+    izip = _builtins.zip
+    imap = _builtins.map
+    from functools import reduce
     xrange = range
     iteritems = lambda d: iter(d.items()) # not dict.items!!! See above
     itervalues = lambda d: iter(d.values())
