@@ -1,14 +1,41 @@
 
 class SlashException(Exception):
-    pass
+
+    @classmethod
+    def throw(cls, *args, **kwargs):
+        raise cls(*args, **kwargs)
+
 
 class NoActiveSession(SlashException):
     pass
 
+
 class CannotLoadTests(SlashException):
     pass
 
+
+class FixtureException(CannotLoadTests):
+    pass
+
+
+class CyclicFixtureDependency(FixtureException):
+    pass
+
+
+class UnresolvedFixtureStore(FixtureException):
+    pass
+
+
+class UnknownFixtures(FixtureException):
+    pass
+
+
+class InvalidFixtureScope(FixtureException):
+    pass
+
+
 class TestFailed(AssertionError):
+
     """
     This exception class distinguishes actual test failures (mostly assertion errors,
     but possibly other conditions as well) from regular asserts.
@@ -18,11 +45,14 @@ class TestFailed(AssertionError):
     """
     pass
 
-class SkipTest(Exception):
+
+class SkipTest(SlashException):
+
     """
     This exception should be raised in order to interrupt the execution of the currently running test, marking
     it as skipped
     """
+
     def __init__(self, reason="Test skipped"):
         super(SkipTest, self).__init__(reason)
         self.reason = reason
