@@ -19,7 +19,13 @@ def set_log_color(logger_name, level, color):
 
 class ConsoleHandler(logbook.more.ColorizedStderrHandler):
 
-    MAX_LINE_LENGTH = 120
+    MAX_LINE_LENGTH = 160
+
+    default_format_string = '[{record.time:%Y-%m-%d %H:%M:%S}] {record.message}'
+
+    def __init__(self, *args, **kwargs):
+        super(ConsoleHandler, self).__init__(*args, **kwargs)
+        self._truncate_lines = config.root.log.truncate_console_lines
 
     def get_color(self, record):
         returned = _custom_colors.get((record.channel, record.level))
@@ -29,7 +35,7 @@ class ConsoleHandler(logbook.more.ColorizedStderrHandler):
 
     def format(self, record):
         result = super(ConsoleHandler, self).format(record)
-        if len(result) > self.MAX_LINE_LENGTH:
+        if self._truncate_lines and len(result) > self.MAX_LINE_LENGTH:
             result = "\n".join(
                 self._truncate(line) for line in result.splitlines())
         return result
@@ -60,7 +66,17 @@ class SessionLogging(object):
     def get_test_logging_context(self):
         with self._get_file_logging_context(config.root.log.subpath, config.root.log.last_test_symlink) as path:
             self.test_log_path = path
-            yield path
+            context.result.set_log_path(path)
+            try:
+                yield path
+            finally:
+                self._create_last_failed_symlink_if_needed()
+
+    def _create_last_failed_symlink_if_needed(self):
+        result = context.result
+        assert result
+        if result.is_error() or result.is_failure():
+            self._try_create_symlink(result.get_log_path(), config.root.log.last_failed_symlink)
 
     @contextmanager
     def get_session_logging_context(self):
@@ -92,17 +108,25 @@ class SessionLogging(object):
             log_path = None
             handler = logbook.NullHandler(bubble=False)
         else:
-            log_path = os.path.join(root_path, subpath.format(context=context))
+            log_path = self._normalize_path(os.path.join(root_path, subpath.format(context=context)))
             ensure_containing_directory(log_path)
             handler = logbook.FileHandler(log_path, bubble=False)
             self._try_create_symlink(log_path, symlink)
             self._set_formatting(handler)
         return handler, log_path
 
+    def _normalize_path(self, p):
+        return os.path.expanduser(p)
+
     def _try_create_symlink(self, path, symlink):
         if symlink is None:
             return
 
+        symlink = self._normalize_path(symlink)
+
+        if not os.path.isabs(symlink):
+            symlink = os.path.join(config.root.log.root, symlink)
+
         try:
             ensure_containing_directory(symlink)
 
